@@ -5,13 +5,14 @@ related utilities used by hledger commands.
 
 -}
 
-{-# LANGUAGE CPP, ScopedTypeVariables, DeriveDataTypeable, FlexibleContexts, TypeFamilies, OverloadedStrings, PackageImports #-}
+{-# LANGUAGE CPP, ScopedTypeVariables, FlexibleContexts, TypeFamilies, OverloadedStrings, PackageImports #-}
 
 module Hledger.Cli.CliOptions (
 
   -- * cmdargs flags & modes
   helpflags,
   detailedversionflag,
+  flattreeflags,
   hiddenflags,
   inputflags,
   reportflags,
@@ -170,13 +171,12 @@ reportflags = [
      ])
  ,flagReq  ["value"]         (\s opts -> Right $ setopt "value" s opts) "TYPE[,COMM]"
    (unlines
-     ["TYPE is cost, end, now or YYYY-MM-DD."
-     ,"COMM is an optional commodity symbol."
-     ,"Shows amounts converted to:"
-     ,"- cost using transaction prices, then optionally to COMM using period-end market prices"
-     ,"- period-end market value, in default valuation commodity or COMM"
-     ,"- current market value, in default valuation commodity or COMM"
-     ,"- market value on the given date, in default valuation commodity or COMM"
+     ["show amounts converted with valuation TYPE, and optionally to specified commodity COMM. TYPE can be:"
+     ,"'cost': convert to cost using transaction prices, then optionally to COMM using period-end market prices"
+     ,"'then': convert to contemporaneous market value, in default valuation commodity or COMM (print & register commands only)"
+     ,"'end':  convert to period-end market value, in default valuation commodity or COMM"
+     ,"'now':  convert to current market value, in default valuation commodity or COMM"
+     ,"YYYY-MM-DD: convert to market value on the given date, in default valuation commodity or COMM"
      ])
  ,flagNone ["infer-value"]   (setboolopt "infer-value") "with -V/-X/--value, also infer market prices from transactions"
 
@@ -188,8 +188,30 @@ reportflags = [
    , "Also, in hledger-ui, make future transactions visible."
    , "Note that = (and not a space) is required before PERIODEXP if you wish to supply it."
    ])
+
+  -- general output-related
+
+ ,flagReq  ["color","colour"] (\s opts -> Right $ setopt "color" s opts) "WHEN"
+   (unlines
+     ["Should color-supporting commands use ANSI color codes in text output."
+     ,"'auto' (default): whenever stdout seems to be a color-supporting terminal."
+     ,"'always' or 'yes': always, useful eg when piping output into 'less -R'."
+     ,"'never' or 'no': never."
+     ,"A NO_COLOR environment variable overrides this."
+     ])
  ]
 
+-- | Flags for selecting flat/tree mode, used for reports organised by account.
+-- With a True argument, shows some extra help about inclusive/exclusive amounts.
+flattreeflags :: Bool -> [Flag RawOpts]
+flattreeflags showamounthelp = [
+   flagNone ["flat","l"] (setboolopt "flat")
+     ("show accounts as a flat list (default)"
+      ++ if showamounthelp then ". Amounts exclude subaccount amounts, except where the account is depth-clipped." else "")
+  ,flagNone ["tree","t"] (setboolopt "tree")
+    ("show accounts as a tree" ++ if showamounthelp then ". Amounts include subaccount amounts." else "")
+  ]
+
 -- | Common flags that are accepted but not shown in --help,
 -- such as --effective, --aux-date.
 hiddenflags :: [Flag RawOpts]
@@ -301,7 +323,7 @@ hledgerCommandMode :: CommandDoc -> [Flag RawOpts] -> [(String, [Flag RawOpts])]
   -> [Flag RawOpts] -> ([Arg RawOpts], Maybe (Arg RawOpts)) -> Mode RawOpts
 hledgerCommandMode doc unnamedflaggroup namedflaggroups hiddenflaggroup argsdescr =
   case parseCommandDoc doc of
-    Nothing -> error' $ "Could not parse command doc:\n"++doc++"\n"
+    Nothing -> error' $ "Could not parse command doc:\n"++doc++"\n"  -- PARTIAL:
     Just (names, shorthelp, longhelplines) ->
       (defCommandMode names) {
          modeHelp        = shorthelp
@@ -391,7 +413,7 @@ data CliOpts = CliOpts {
                                         -- 1. the COLUMNS env var, if set
                                         -- 2. the width reported by the terminal, if supported
                                         -- 3. the default (80)
- } deriving (Show, Data, Typeable)
+ } deriving (Show)
 
 instance Default CliOpts where def = defcliopts
 
@@ -446,7 +468,7 @@ rawOptsToCliOpts rawopts = checkCliOpts <$> do
              ,reportopts_      = ropts
              ,output_file_     = maybestringopt "output-file" rawopts
              ,output_format_   = maybestringopt "output-format" rawopts
-             ,debug_           = intopt "debug" rawopts
+             ,debug_           = posintopt "debug" rawopts
              ,no_new_accounts_ = boolopt "no-new-accounts" rawopts -- add
              ,width_           = maybestringopt "width" rawopts
              ,available_width_ = availablewidth
