@@ -36,12 +36,12 @@ import Hledger.Cli.CliOptions
 -- | Command line options for this command.
 accountsmode = hledgerCommandMode
   $(embedFileRelative "Hledger/Cli/Commands/Accounts.txt")
-  [flagNone ["declared"] (setboolopt "declared") "show account names declared with account directives"
+  ([flagNone ["declared"] (setboolopt "declared") "show account names declared with account directives"
   ,flagNone ["used"] (setboolopt "used") "show account names referenced by transactions"
-  ,flagNone ["tree"] (setboolopt "tree") "show short account names, as a tree"
-  ,flagNone ["flat"] (setboolopt "flat") "show full account names, as a list (default)"
-  ,flagReq  ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "flat mode: omit N leading account name parts"
   ]
+  ++ flattreeflags False ++
+  [flagReq  ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "flat mode: omit N leading account name parts"
+  ])
   [generalflagsgroup1]
   hiddenflags
   ([], Just $ argsFlag "[QUERY]")
@@ -74,16 +74,18 @@ accounts CliOpts{rawopts_=rawopts, reportopts_=ropts} j = do
   -- 3. if there's a depth limit, depth-clip and remove any no longer useful items
       clippedaccts =
         dbg1 "clippedaccts" $
-        filter (matchesAccount acctq) $  -- clipping can leave accounts that no longer match the query, remove such
-        nub $                          -- clipping can leave duplicates (adjacent, hopefully)
-        filter (not . T.null) $        -- depth:0 can leave nulls
+        filter (matchesAccount acctq) $           -- clipping can leave accounts that no longer match the query, remove such
+        nub $                                     -- clipping can leave duplicates (adjacent, hopefully)
+        filter (not . T.null) $                   -- depth:0 can leave nulls
         map (clipAccountName depth) $  -- clip at depth if specified
         sortedaccts
 
   -- 4. print what remains as a list or tree, maybe applying --drop in the former case
   mapM_ (T.putStrLn . render) clippedaccts
     where
-      render a
-        | tree_ ropts = T.replicate (2 * (accountNameLevel a - 1)) " " <> accountLeafName a
-        | otherwise   = accountNameDrop (drop_ ropts) a
-
+      render a = case accountlistmode_ ropts of
+          ALTree -> T.replicate indent " " <> accountLeafName droppedName
+          ALFlat -> droppedName
+        where
+          indent = 2 * (max 0 (accountNameLevel a - drop_ ropts) - 1)
+          droppedName = accountNameDrop (drop_ ropts) a
