@@ -3,7 +3,7 @@ A history-aware add command to help with data entry.
 |-}
 
 {-# OPTIONS_GHC -fno-warn-missing-signatures -fno-warn-unused-do-bind #-}
-{-# LANGUAGE ScopedTypeVariables, DeriveDataTypeable, RecordWildCards, TypeOperators, FlexibleContexts, OverloadedStrings, PackageImports, LambdaCase #-}
+{-# LANGUAGE ScopedTypeVariables, RecordWildCards, TypeOperators, FlexibleContexts, OverloadedStrings, PackageImports, LambdaCase #-}
 {-# LANGUAGE TemplateHaskell #-}
 
 module Hledger.Cli.Commands.Add (
@@ -32,7 +32,6 @@ import Data.Text (Text)
 import qualified Data.Text as T
 import Data.Time.Calendar (Day)
 import Data.Time.Format (formatTime, defaultTimeLocale, iso8601DateFormat)
-import Data.Typeable (Typeable)
 import Safe (headDef, headMay, atMay)
 import System.Console.CmdArgs.Explicit
 import System.Console.Haskeline (runInputT, defaultSettings, setComplete)
@@ -54,7 +53,7 @@ addmode = hledgerCommandMode
   [flagNone ["no-new-accounts"]  (setboolopt "no-new-accounts") "don't allow creating new accounts"]
   [generalflagsgroup2]
   []
-  ([], Just $ argsFlag "[QUERY]")
+  ([], Just $ argsFlag "[DATE [DESCRIPTION [ACCOUNT1 [AMOUNT1 [ACCOUNT2 [ETC...]]]]]]")
 
 -- | State used while entering transactions.
 data EntryState = EntryState {
@@ -65,7 +64,7 @@ data EntryState = EntryState {
   ,esJournal            :: Journal           -- ^ the journal we are adding to
   ,esSimilarTransaction :: Maybe Transaction -- ^ the most similar historical txn
   ,esPostings           :: [Posting]         -- ^ postings entered so far in the current txn
-  } deriving (Show,Typeable)
+  } deriving (Show)
 
 defEntryState = EntryState {
    esOpts               = defcliopts
@@ -77,10 +76,10 @@ defEntryState = EntryState {
   ,esPostings           = []
 }
 
-data RestartTransactionException = RestartTransactionException deriving (Typeable,Show)
+data RestartTransactionException = RestartTransactionException deriving (Show)
 instance Exception RestartTransactionException
 
--- data ShowHelpException = ShowHelpException deriving (Typeable,Show)
+-- data ShowHelpException = ShowHelpException deriving (Show)
 -- instance Exception ShowHelpException
 
 -- | Read multiple transactions from the console, prompting for each
@@ -121,7 +120,7 @@ getAndAddTransactions es@EntryState{..} = (do
   let defaultPrevInput = PrevInput{prevDateAndCode=Nothing, prevDescAndCmnt=Nothing, prevAccount=[], prevAmountAndCmnt=[]}
   mt <- runInputT (setComplete noCompletion defaultSettings) (System.Console.Wizard.run $ haskeline $ confirmedTransactionWizard defaultPrevInput es [])
   case mt of
-    Nothing -> error "Could not interpret the input, restarting"  -- caught below causing a restart, I believe
+    Nothing -> error "Could not interpret the input, restarting"  -- caught below causing a restart, I believe  -- PARTIAL:
     Just t -> do
       j <- if debug_ esOpts > 0
            then do hPrintf stderr "Skipping journal add due to debug mode.\n"
@@ -279,7 +278,7 @@ dateAndCodeWizard PrevInput{..} EntryState{..} = do
             dateandcodep = do
                 d <- smartdate
                 c <- optional codep
-                skipMany spacenonewline
+                skipNonNewlineSpaces
                 eof
                 return (d, fromMaybe "" c)
       -- defday = fixSmartDate today $ fromparse $ (parse smartdate "" . lowercase) defdate
@@ -356,7 +355,7 @@ amountAndCommentWizard PrevInput{..} EntryState{..} = do
       amountandcommentp :: JournalParser Identity (Amount, Text)
       amountandcommentp = do
         a <- amountp
-        lift (skipMany spacenonewline)
+        lift skipNonNewlineSpaces
         c <- T.pack <$> fromMaybe "" `fmap` optional (char ';' >> many anySingle)
         -- eof
         return (a,c)
@@ -371,7 +370,7 @@ amountAndCommentWizard PrevInput{..} EntryState{..} = do
                   -- 4 maximum precision entered so far in this transaction ?
                   -- 5 3 or 4, whichever would show the most decimal places ?
                   -- I think 1 or 4, whichever would show the most decimal places
-                  maxprecisionwithpoint
+                  NaturalPrecision
   --
   -- let -- (amt,comment) = (strip a, strip $ dropWhile (==';') b) where (a,b) = break (==';') amtcmt
       -- a           = fromparse $ runParser (amountp <|> return missingamt) (jparsestate esJournal) "" amt
