@@ -258,6 +258,7 @@ import Data.Maybe
 --import qualified Data.Map as Map
 import qualified Data.Text as T
 import qualified Data.Text.Lazy as TL
+import Data.Time (fromGregorian)
 import System.Console.CmdArgs.Explicit as C
 import Lucid as L
 import Text.Printf (printf)
@@ -279,20 +280,20 @@ balancemode = hledgerCommandMode
       "show balance change accumulated across periods (in multicolumn reports)"
    ,flagNone ["historical","H"] (setboolopt "historical")
       "show historical ending balance in each period (includes postings before report start date)\n "
-   ,flagNone ["tree"] (setboolopt "tree") "show accounts as a tree; amounts include subaccounts (default in simple reports)"
-   ,flagNone ["flat"] (setboolopt "flat") "show accounts as a list; amounts exclude subaccounts except when account is depth-clipped (default in multicolumn reports)\n "
+   ]
+   ++ flattreeflags True ++
+   [flagReq  ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "omit N leading account name parts (in flat mode)"
    ,flagNone ["average","A"] (setboolopt "average") "show a row average column (in multicolumn reports)"
    ,flagNone ["row-total","T"] (setboolopt "row-total") "show a row total column (in multicolumn reports)"
    ,flagNone ["no-total","N"] (setboolopt "no-total") "omit the final total row"
-   ,flagReq  ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "omit N leading account name parts (in flat mode)"
    ,flagNone ["no-elide"] (setboolopt "no-elide") "don't squash boring parent accounts (in tree mode)"
    ,flagReq  ["format"] (\s opts -> Right $ setopt "format" s opts) "FORMATSTR" "use this custom line format (in simple reports)"
    ,flagNone ["pretty-tables"] (setboolopt "pretty-tables") "use unicode to display prettier tables"
    ,flagNone ["sort-amount","S"] (setboolopt "sort-amount") "sort by amount instead of account code/name (in flat mode). With multiple columns, sorts by the row total, or by row average if that is displayed."
-   ,flagNone ["budget"] (setboolopt "budget") "show performance compared to budget goals defined by periodic transactions"
+   ,flagNone ["percent", "%"] (setboolopt "percent") "express values in percentage of each column's total"
    ,flagNone ["invert"] (setboolopt "invert") "display all amounts with reversed sign"
    ,flagNone ["transpose"] (setboolopt "transpose") "transpose rows and columns"
-   ,flagNone ["percent", "%"] (setboolopt "percent") "express values in percentage of each column's total"
+   ,flagNone ["budget"] (setboolopt "budget") "show performance compared to budget goals defined by periodic transactions"
    ,outputFormatFlag ["txt","html","csv","json"]
    ,outputFileFlag
    ]
@@ -306,7 +307,7 @@ balance :: CliOpts -> Journal -> IO ()
 balance opts@CliOpts{rawopts_=rawopts,reportopts_=ropts@ReportOpts{..}} j = do
   d <- getCurrentDay
   case lineFormatFromOpts ropts of
-    Left err -> error' $ unlines [err]
+    Left err -> error' $ unlines [err]  -- PARTIAL:
     Right _ -> do
       let budget      = boolopt "budget" rawopts
           multiperiod = interval_ /= NoInterval
@@ -314,9 +315,9 @@ balance opts@CliOpts{rawopts_=rawopts,reportopts_=ropts@ReportOpts{..}} j = do
 
       if budget then do  -- single or multi period budget report
         reportspan <- reportSpan j ropts
-        let budgetreport     = dbg1 "budgetreport"     $ budgetReport ropts assrt reportspan d j
+        let budgetreport = dbg4 "budgetreport" $ budgetReport ropts assrt reportspan d j
               where
-                assrt          = not $ ignore_assertions_ $ inputopts_ opts
+                assrt = not $ ignore_assertions_ $ inputopts_ opts
             render = case fmt of
               "txt"  -> budgetReportAsText ropts
               "json" -> (++"\n") . TL.unpack . toJsonText
@@ -335,13 +336,7 @@ balance opts@CliOpts{rawopts_=rawopts,reportopts_=ropts@ReportOpts{..}} j = do
           writeOutput opts $ render report
 
         else do  -- single period simple balance report
-          let report
-                | balancetype_ `elem` [HistoricalBalance, CumulativeChange]
-                  = let ropts' | flat_ ropts = ropts
-                               | otherwise   = ropts{accountlistmode_=ALTree}
-                    in balanceReportFromMultiBalanceReport ropts' (queryFromOpts d ropts) j
-                          -- for historical balances we must use balanceReportFromMultiBalanceReport (also forces --no-elide)
-                | otherwise = balanceReport ropts (queryFromOpts d ropts) j -- simple Ledger-style balance report
+          let report = balanceReport ropts (queryFromOpts d ropts) j -- simple Ledger-style balance report
               render = case fmt of
                 "txt"  -> balanceReportAsText
                 "csv"  -> \ropts r -> (++ "\n") $ printCSV $ balanceReportAsCsv ropts r
@@ -355,11 +350,11 @@ balance opts@CliOpts{rawopts_=rawopts,reportopts_=ropts@ReportOpts{..}} j = do
 balanceReportAsCsv :: ReportOpts -> BalanceReport -> CSV
 balanceReportAsCsv opts (items, total) =
   ["account","balance"] :
-  [[T.unpack (maybeAccountNameDrop opts a), showMixedAmountOneLineWithoutPrice b] | (a, _, _, b) <- items]
+  [[T.unpack a, showMixedAmountOneLineWithoutPrice False b] | (a, _, _, b) <- items]
   ++
   if no_total_ opts
   then []
-  else [["total", showMixedAmountOneLineWithoutPrice total]]
+  else [["total", showMixedAmountOneLineWithoutPrice False total]]
 
 -- | Render a single-column balance report as plain text.
 balanceReportAsText :: ReportOpts -> BalanceReport -> String
@@ -404,7 +399,7 @@ This implementation turned out to be a bit convoluted but implements the followi
 balanceReportItemAsText :: ReportOpts -> StringFormat -> BalanceReportItem -> [String]
 balanceReportItemAsText opts fmt (_, accountName, depth, amt) =
   renderBalanceReportItem opts fmt (
-    maybeAccountNameDrop opts accountName,
+    accountName,
     depth,
     normaliseMixedAmountSquashPricesForDisplay amt
     )
@@ -432,10 +427,7 @@ renderComponent opts (acctname, depth, total) (FormatField ljust min max field)
                                  Just m  -> depth * m
                                  Nothing -> depth
   AccountField     -> formatString ljust min max (T.unpack acctname)
-  TotalField       -> fitStringMulti min max True False $ showamt total
-    where
-      showamt | color_ opts = cshowMixedAmountWithoutPrice
-              | otherwise   = showMixedAmountWithoutPrice
+  TotalField       -> fitStringMulti min max True False $ showMixedAmountWithoutPrice (color_ opts) total
   _                -> ""
 
 -- | Render one StringFormat component for a balance report item.
@@ -452,8 +444,7 @@ renderComponent1 opts (acctname, depth, total) (FormatField ljust min max field)
                         indented = ((replicate (depth*2) ' ')++)
   TotalField       -> fitStringMulti min max True False $ ((intercalate ", " . map strip . lines) (showamt total))
     where
-      showamt | color_ opts = cshowMixedAmountWithoutPrice
-              | otherwise   = showMixedAmountWithoutPrice
+      showamt = showMixedAmountWithoutPrice (color_ opts)
   _                -> ""
 
 -- rendering multi-column balance reports
@@ -463,23 +454,23 @@ renderComponent1 opts (acctname, depth, total) (FormatField ljust min max field)
 -- and will include the final totals row unless --no-total is set.
 multiBalanceReportAsCsv :: ReportOpts -> MultiBalanceReport -> CSV
 multiBalanceReportAsCsv opts@ReportOpts{average_, row_total_}
-    (PeriodicReport colspans items (PeriodicReportRow _ _ coltotals tot avg)) =
+    (PeriodicReport colspans items (PeriodicReportRow _ coltotals tot avg)) =
   maybetranspose $
   ("Account" : map showDateSpan colspans
    ++ ["Total"   | row_total_]
    ++ ["Average" | average_]
   ) :
-  [T.unpack (maybeAccountNameDrop opts a) :
-   map showMixedAmountOneLineWithoutPrice
+  [T.unpack (displayFull a) :
+   map (showMixedAmountOneLineWithoutPrice False)
    (amts
     ++ [rowtot | row_total_]
     ++ [rowavg | average_])
-  | PeriodicReportRow a _ amts rowtot rowavg <- items]
+  | PeriodicReportRow a amts rowtot rowavg <- items]
   ++
   if no_total_ opts
   then []
   else ["Total:" :
-        map showMixedAmountOneLineWithoutPrice (
+        map (showMixedAmountOneLineWithoutPrice False) (
           coltotals
           ++ [tot | row_total_]
           ++ [avg | average_]
@@ -504,7 +495,7 @@ multiBalanceReportAsHtml ropts mbr =
 multiBalanceReportHtmlRows :: ReportOpts -> MultiBalanceReport -> (Html (), [Html ()], Maybe (Html ()))
 multiBalanceReportHtmlRows ropts mbr =
   let
-    headingsrow:rest | transpose_ ropts = error' "Sorry, --transpose is not supported with HTML output yet"
+    headingsrow:rest | transpose_ ropts = error' "Sorry, --transpose is not supported with HTML output yet"  -- PARTIAL:
                      | otherwise = multiBalanceReportAsCsv ropts mbr
     (bodyrows, mtotalsrow) | no_total_ ropts = (rest,      Nothing)
                            | otherwise       = (init rest, Just $ last rest)
@@ -591,7 +582,7 @@ multiBalanceReportAsText ropts@ReportOpts{..} r =
       (showDateSpan $ periodicReportSpan r)
       (case value_ of
         Just (AtCost _mc)   -> ", valued at cost"
-        Just (AtThen _mc)   -> error' unsupportedValueThenError  -- TODO -- ", valued at period ends"  -- handled like AtEnd for now
+        Just (AtThen _mc)   -> error' unsupportedValueThenError  -- TODO -- ", valued at period ends"  -- handled like AtEnd for now  -- PARTIAL:
         Just (AtEnd _mc)    -> ", valued at period ends"
         Just (AtNow _mc)    -> ", current value"
         -- XXX duplicates the above
@@ -603,7 +594,7 @@ multiBalanceReportAsText ropts@ReportOpts{..} r =
 -- | Build a 'Table' from a multi-column balance report.
 balanceReportAsTable :: ReportOpts -> MultiBalanceReport -> Table String String MixedAmount
 balanceReportAsTable opts@ReportOpts{average_, row_total_, balancetype_}
-    (PeriodicReport colspans items (PeriodicReportRow _ _ coltotals tot avg)) =
+    (PeriodicReport spans items (PeriodicReportRow _ coltotals tot avg)) =
    maybetranspose $
    addtotalrow $
    Table
@@ -612,17 +603,13 @@ balanceReportAsTable opts@ReportOpts{average_, row_total_, balancetype_}
      (map rowvals items)
   where
     totalscolumn = row_total_ && balancetype_ `notElem` [CumulativeChange, HistoricalBalance]
-    mkDate = case balancetype_ of
-       PeriodChange -> showDateSpanMonthAbbrev
-       _            -> maybe "" (showDate . prevday) . spanEnd
-    colheadings = map mkDate colspans
+    colheadings = map (reportPeriodName balancetype_ spans) spans
                   ++ ["  Total" | totalscolumn]
                   ++ ["Average" | average_]
     accts = map renderacct items
-    renderacct (PeriodicReportRow a i _ _ _)
-      | tree_ opts = replicate ((i-1)*2) ' ' ++ T.unpack (accountLeafName a)
-      | otherwise  = T.unpack $ maybeAccountNameDrop opts a
-    rowvals (PeriodicReportRow _ _ as rowtot rowavg) = as
+    renderacct row =
+        replicate ((prrDepth row - 1) * 2) ' ' ++ T.unpack (prrDisplayName row)
+    rowvals (PeriodicReportRow _ as rowtot rowavg) = as
                              ++ [rowtot | totalscolumn]
                              ++ [rowavg | average_]
     addtotalrow | no_total_ opts = id
@@ -636,12 +623,14 @@ balanceReportAsTable opts@ReportOpts{average_, row_total_, balancetype_}
 
 -- | Given a table representing a multi-column balance report (for example,
 -- made using 'balanceReportAsTable'), render it in a format suitable for
--- console output.
+-- console output. Amounts with more than two commodities will be elided
+-- unless --no-elide is used.
 balanceReportTableAsText :: ReportOpts -> Table String String MixedAmount -> String
-balanceReportTableAsText ropts = tableAsText ropts showamt
+balanceReportTableAsText ropts@ReportOpts{..} = tableAsText ropts showamt
   where
-    showamt | color_ ropts = cshowMixedAmountOneLineWithoutPrice
-            | otherwise    =  showMixedAmountOneLineWithoutPrice
+    showamt
+      | no_elide_ = showMixedAmountOneLineWithoutPrice color_
+      | otherwise = showMixedAmountElided color_
 
 
 tests_Balance = tests "Balance" [
@@ -650,7 +639,7 @@ tests_Balance = tests "Balance" [
     test "unicode in balance layout" $ do
       j <- readJournal' "2009/01/01 * медвежья шкура\n  расходы:покупки  100\n  актив:наличные\n"
       let opts = defreportopts
-      balanceReportAsText opts (balanceReport opts (queryFromOpts (parsedate "2008/11/26") opts) j)
+      balanceReportAsText opts (balanceReport opts (queryFromOpts (fromGregorian 2008 11 26) opts) j)
         @?=
         unlines
         ["                -100  актив:наличные"
