@@ -1,4 +1,5 @@
-{-# LANGUAGE QuasiQuotes, RecordWildCards #-}
+{-# LANGUAGE RecordWildCards #-}
+{-# LANGUAGE TemplateHaskell #-}
 {-|
 
 The @balancesheet@ command prints a simple balance sheet.
@@ -10,7 +11,6 @@ module Hledger.Cli.Commands.Balancesheet (
  ,balancesheet
 ) where
 
-import Data.String.Here
 import System.Console.CmdArgs.Explicit
 
 import Hledger
@@ -18,18 +18,7 @@ import Hledger.Cli.CliOptions
 import Hledger.Cli.CompoundBalanceCommand
 
 balancesheetSpec = CompoundBalanceCommandSpec {
-  cbcname     = "balancesheet",
-  cbcaliases  = ["bs"],
-  cbchelp     = [here|
-This command displays a simple balance sheet, showing historical ending
-balances of asset and liability accounts (ignoring any report begin date). 
-It assumes that these accounts are under a top-level `asset` or `liability`
-account (case insensitive, plural forms also  allowed).
-
-Note this report shows all account balances with normal positive sign
-(like conventional financial statements, unlike balance/print/register)
-(experimental).
-  |],
+  cbcdoc      = $(embedFileRelative "Hledger/Cli/Commands/Balancesheet.txt"),
   cbctitle    = "Balance Sheet",
   cbcqueries  = [
      CBCSubreportSpec{
