@@ -1,4 +1,5 @@
 {-# LANGUAGE QuasiQuotes, RecordWildCards #-}
+{-# LANGUAGE TemplateHaskell #-}
 {-|
 
 The @balancesheetequity@ command prints a simple balance sheet.
@@ -10,7 +11,6 @@ module Hledger.Cli.Commands.Balancesheetequity (
  ,balancesheetequity
 ) where
 
-import Data.String.Here
 import System.Console.CmdArgs.Explicit
 
 import Hledger
@@ -18,17 +18,7 @@ import Hledger.Cli.CliOptions
 import Hledger.Cli.CompoundBalanceCommand
 
 balancesheetequitySpec = CompoundBalanceCommandSpec {
-  cbcname     = "balancesheetequity",
-  cbcaliases  = ["bse"],
-  cbchelp     = [here|This command displays a simple balance sheet, showing historical ending
-balances of asset, liability and equity accounts (ignoring any report begin date). 
-It assumes that these accounts are under a top-level `asset`, `liability` and `equity`
-account (plural forms also  allowed).
-
-Note this report shows all account balances with normal positive sign
-(like conventional financial statements, unlike balance/print/register)
-(experimental).
-  |],
+  cbcdoc      = $(embedFileRelative "Hledger/Cli/Commands/Balancesheetequity.txt"),
   cbctitle    = "Balance Sheet With Equity",
   cbcqueries  = [
      CBCSubreportSpec{
