@@ -1,4 +1,5 @@
 {-# LANGUAGE QuasiQuotes, RecordWildCards #-}
+{-# LANGUAGE TemplateHaskell #-}
 {-|
 
 The @cashflow@ command prints a simplified cashflow statement.  It just
@@ -13,7 +14,6 @@ module Hledger.Cli.Commands.Cashflow (
  ,cashflow
 ) where
 
-import Data.String.Here
 import System.Console.CmdArgs.Explicit
 
 import Hledger
@@ -21,18 +21,7 @@ import Hledger.Cli.CliOptions
 import Hledger.Cli.CompoundBalanceCommand
 
 cashflowSpec = CompoundBalanceCommandSpec {
-  cbcname     = "cashflow",
-  cbcaliases  = ["cf"],
-  cbchelp     = [here|
-This command displays a simple cashflow statement, showing changes
-in "cash" accounts. It assumes that these accounts are under a top-level 
-`asset` account (case insensitive, plural forms also allowed) and do not 
-contain `receivable` or `A/R` in their name. 
-
-Note this report shows all account balances with normal positive sign
-(like conventional financial statements, unlike balance/print/register)
-(experimental).
-  |],
+  cbcdoc      = $(embedFileRelative "Hledger/Cli/Commands/Cashflow.txt"),
   cbctitle    = "Cashflow Statement",
   cbcqueries  = [
      CBCSubreportSpec{
