@@ -23,6 +23,7 @@ import Data.Maybe
 -- import Data.Text (Text)
 import qualified Data.Text as T
 import qualified Data.Text.Lazy as TL
+import Data.Time (fromGregorian)
 import System.Console.CmdArgs.Explicit
 import Hledger.Read.CsvReader (CSV, CsvRecord, printCSV)
 
@@ -64,7 +65,7 @@ register opts@CliOpts{reportopts_=ropts} j = do
       render | fmt=="txt"  = postingsReportAsText
              | fmt=="csv"  = const ((++"\n") . printCSV . postingsReportAsCsv)
              | fmt=="json" = const ((++"\n") . TL.unpack . toJsonText)
-             | otherwise   = const $ error' $ unsupportedOutputFormatError fmt
+             | otherwise   = const $ error' $ unsupportedOutputFormatError fmt  -- PARTIAL:
   writeOutput opts $ render opts $ postingsReport ropts (queryFromOpts d ropts) j
 
 postingsReportAsCsv :: PostingsReport -> CSV
@@ -86,8 +87,8 @@ postingsReportItemAsCsvRecord (_, _, _, p, b) = [idx,date,code,desc,acct,amt,bal
                              BalancedVirtualPosting -> (\s -> "["++s++"]")
                              VirtualPosting -> (\s -> "("++s++")")
                              _ -> id
-    amt = showMixedAmountOneLineWithoutPrice $ pamount p
-    bal = showMixedAmountOneLineWithoutPrice b
+    amt = showMixedAmountOneLineWithoutPrice False $ pamount p
+    bal = showMixedAmountOneLineWithoutPrice False b
 
 -- | Render a register report as plain text suitable for console output.
 postingsReportAsText :: CliOpts -> PostingsReport -> String
@@ -179,8 +180,7 @@ postingsReportItemAsText opts preferredamtwidth preferredbalwidth (mdate, mendda
               BalancedVirtualPosting -> (\s -> "["++s++"]", acctwidth-2)
               VirtualPosting         -> (\s -> "("++s++")", acctwidth-2)
               _                      -> (id,acctwidth)
-      showamt | color_ (reportopts_ opts) = cshowMixedAmountWithoutPrice
-              | otherwise                 = showMixedAmountWithoutPrice
+      showamt = showMixedAmountWithoutPrice (color_ $ reportopts_ opts)
       amt = showamt $ pamount p
       bal = showamt b
       -- alternate behaviour, show null amounts as 0 instead of blank
@@ -201,7 +201,7 @@ tests_Register = tests "Register" [
     test "unicode in register layout" $ do
       j <- readJournal' "2009/01/01 * медвежья шкура\n  расходы:покупки  100\n  актив:наличные\n"
       let opts = defreportopts
-      (postingsReportAsText defcliopts $ postingsReport opts (queryFromOpts (parsedate "2008/11/26") opts) j)
+      (postingsReportAsText defcliopts $ postingsReport opts (queryFromOpts (fromGregorian 2008 11 26) opts) j)
         @?=
         unlines
         ["2009-01-01 медвежья шкура       расходы:покупки                100           100"
