@@ -82,14 +82,14 @@ mainmode addons = defMode {
         [detailedversionflag]
         -- ++ inputflags -- included here so they'll not raise a confusing error if present with no COMMAND
     }
- ,modeHelpSuffix = map (regexReplace "PROGNAME" progname) [
-     "Examples:"
-    ,"PROGNAME                         list commands"
-    ,"PROGNAME CMD [--] [OPTS] [ARGS]  run a command (use -- with addon commands)"
-    ,"PROGNAME-CMD [OPTS] [ARGS]       or run addon commands directly"
-    ,"PROGNAME -h                      show general usage"
-    ,"PROGNAME CMD -h                  show command usage"
-    ,"PROGNAME help [MANUAL]           show any of the hledger manuals in various formats"
+ ,modeHelpSuffix = "Examples:" :
+    map (progname ++) [
+     "                         list commands"
+    ," CMD [--] [OPTS] [ARGS]  run a command (use -- with addon commands)"
+    ,"-CMD [OPTS] [ARGS]       or run addon commands directly"
+    ," -h                      show general usage"
+    ," CMD -h                  show command usage"
+    ," help [MANUAL]           show any of the hledger manuals in various formats"
     ]
  }
 
@@ -115,7 +115,7 @@ main = do
     (argsbeforecmd, argsaftercmd') = break (==rawcmd) args
     argsaftercmd         = drop 1 argsaftercmd'
     dbgIO :: Show a => String -> a -> IO ()
-    dbgIO = ptraceAtIO 6
+    dbgIO = ptraceAtIO 8
 
   dbgIO "running" prognameandversion
   dbgIO "raw args" args
@@ -140,7 +140,7 @@ main = do
     hasVersion           = ("--version" `elem`)
     hasDetailedVersion   = ("--version+" `elem`)
     printUsage           = putStr $ showModeUsage $ mainmode addons
-    badCommandError      = error' ("command "++rawcmd++" is not recognized, run with no command to see a list") >> exitFailure
+    badCommandError      = error' ("command "++rawcmd++" is not recognized, run with no command to see a list") >> exitFailure  -- PARTIAL:
     hasHelpFlag args     = any (`elem` args) ["-h","--help"]
     f `orShowHelp` mode
       | hasHelpFlag args = putStr $ showModeUsage mode
