@@ -73,7 +73,7 @@ withJournalDo opts cmd = do
   journalpaths <- journalFilePathFromOpts opts
   readJournalFiles (inputopts_ opts) journalpaths
   >>= mapM (journalTransform opts)
-  >>= either error' cmd
+  >>= either error' cmd  -- PARTIAL:
 
 -- | Apply some extra post-parse transformations to the journal, if
 -- specified by options. These happen after journal validation, but
@@ -108,10 +108,12 @@ anonymiseByOpts opts =
 -- | Generate periodic transactions from all periodic transaction rules in the journal.
 -- These transactions are added to the in-memory Journal (but not the on-disk file).
 --
--- They can start no earlier than: the day following the latest normal
--- transaction in the journal (or today if there are none).
--- They end on or before the specified report end date, or 180 days
--- from today if unspecified.
+-- When --auto is active, auto posting rules will be applied to the
+-- generated transactions. If the query in any auto posting rule fails
+-- to parse, this function will raise an error.
+--
+-- The start & end date for generated periodic transactions are determined in
+-- a somewhat complicated way; see the hledger manual -> Periodic transactions.
 --
 journalAddForecast :: CliOpts -> Journal -> IO Journal
 journalAddForecast CliOpts{inputopts_=iopts, reportopts_=ropts} j = do
@@ -136,7 +138,9 @@ journalAddForecast CliOpts{inputopts_=iopts, reportopts_=ropts} j = do
                        , spanContainsDate forecastspan (tdate t)
                        ]
       -- With --auto enabled, transaction modifiers are also applied to forecast txns
-      forecasttxns' = (if auto_ iopts then modifyTransactions (jtxnmodifiers j) else id) forecasttxns
+      forecasttxns' =
+        (if auto_ iopts then either error' id . modifyTransactions today (jtxnmodifiers j) else id)  -- PARTIAL:
+        forecasttxns
 
   return $
     case forecast_ ropts of
@@ -146,7 +150,7 @@ journalAddForecast CliOpts{inputopts_=iopts, reportopts_=ropts} j = do
     journalBalanceTransactions' iopts j =
       let assrt = not . ignore_assertions_ $ iopts
       in
-       either error' id $ journalBalanceTransactions assrt j
+       either error' id $ journalBalanceTransactions assrt j  -- PARTIAL:
 
 -- | Write some output to stdout or to a file selected by --output-file.
 -- If the file exists it will be overwritten.
@@ -299,7 +303,7 @@ tests_Cli_Utils = tests "Utils" [
   --            -- all prices for consistent timing.
   --            let ropts = defreportopts{
   --              value_=True,
-  --              period_=PeriodTo $ parsedate "3000-01-01"
+  --              period_=PeriodTo $ fromGregorian 3000 01 01
   --              }
   --            j' <- journalApplyValue ropts j
   --            sum (journalAmounts j') `seq` return ()
